@@ -378,7 +378,7 @@ class BankReconciliation(ModelSQL):
         super(BankReconciliation, cls).__setup__()
         cls._error_messages.update({
                 'delete_reconciled': ('Bank Reconciliation Line with amount '
-                    '"%(amount)s" in statement_line "%(statement_line)s" '
+                    '"%(amount)s" in statement line "%(statement_line)s" '
                     'cannot be deleted')
                 })
 
